======================
Manipulation/selection
======================

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Series.alias
    Series.append
    Series.arg_sort
    Series.bottom_k
    Series.cast
    Series.ceil
    Series.clear
    Series.clip
    Series.clip_max
    Series.clip_min
    Series.clone
    Series.cut
    Series.drop_nans
    Series.drop_nulls
    Series.explode
    Series.extend
    Series.extend_constant
    Series.fill_nan
    Series.fill_null
    Series.filter
    Series.floor
    Series.gather
    Series.gather_every
    Series.head
    Series.interpolate
    Series.item
    Series.limit
    Series.new_from_index
    Series.qcut
    Series.rechunk
    Series.rename
    Series.reshape
    Series.reverse
    Series.rle
    Series.rle_id
    Series.round
    Series.round_sig_figs
    Series.sample
    Series.scatter
    Series.set
    Series.set_at_idx
    Series.shift
    Series.shift_and_fill
    Series.shrink_dtype
    Series.shrink_to_fit
    Series.shuffle
    Series.slice
    Series.sort
    Series.tail
    Series.take
    Series.take_every
    Series.to_dummies
    Series.top_k
    Series.unique
    Series.view
    Series.zip_with
